Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1852)

Unified Diff: chrome/browser/ui/views/try_chrome_dialog_view.h

Issue 2904823002: Inactive toast ux changes (Closed)
Patch Set: minor rename (x -> horizontal) Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/try_chrome_dialog_view.h
diff --git a/chrome/browser/ui/views/try_chrome_dialog_view.h b/chrome/browser/ui/views/try_chrome_dialog_view.h
index 004cbbc63c1cfd2c72494a5863e108934b29bf11..708c4c3dda9af860a9f3058fc2723261c0f55e04 100644
--- a/chrome/browser/ui/views/try_chrome_dialog_view.h
+++ b/chrome/browser/ui/views/try_chrome_dialog_view.h
@@ -9,52 +9,35 @@
#include "base/compiler_specific.h"
#include "base/macros.h"
+#include "base/time/time.h"
+#include "chrome/browser/ui/startup/startup_browser_creator.h"
+#include "chrome/installer/util/experiment_storage.h"
+#include "ui/gfx/font_list.h"
#include "ui/gfx/geometry/rect.h"
#include "ui/gfx/geometry/size.h"
#include "ui/gfx/native_widget_types.h"
#include "ui/views/controls/button/button.h"
-#include "ui/views/controls/link_listener.h"
+#include "url/gurl.h"
grt (UTC plus 2) 2017/06/22 20:34:04 unused?
skare_ 2017/06/22 23:25:18 Done.
namespace views {
-class RadioButton;
-class Checkbox;
class Widget;
}
// This class displays a modal dialog using the views system. The dialog asks
-// the user to give chrome another try. This class only handles the UI so the
-// resulting actions are up to the caller. One flavor looks like this:
+// the user to give Chrome another try. This class only handles the UI so the
+// resulting actions are up to the caller.
//
-// +-----------------------------------------------+
-// | |icon| There is a new, safer version [x] |
-// | |icon| of Google Chrome available |
-// | [o] Try it out (already installed) |
-// | [ ] Uninstall Google Chrome |
-// | [ OK ] [Don't bug me] |
-// | _why_am_I_seeing this?_ |
-// +-----------------------------------------------+
+// The layout is as follows:
//
-// Another flavor looks like:
// +-----------------------------------------------+
-// | |icon| There is a new, safer version [x] |
-// | |icon| of Google Chrome available |
-// | [o] Try it out (already installed) |
-// | [ ] Don't bug me |
-// | [ OK ] |
+// | |icon| Header text. [x] |
+// | |
+// | Body text. |
+// | [ Open Chrome ] [No Thanks] |
// +-----------------------------------------------+
//
-// And the 2013 version looks like:
-// +-----------------------------------------------+
-// | |icon| There is a new version of [x] |
-// | |icon| Google Chrome available |
-// | [o] Try it out (already installed) |
-// | [ ] Don't bug me |
-// | --------------------------------------------- |
-// | [x] Make it the default browser [ OK ] |
-// +-----------------------------------------------+
-
-class TryChromeDialogView : public views::ButtonListener,
- public views::LinkListener {
+// Some variants do not have body text, or only have one button.
+class TryChromeDialogView : public views::ButtonListener {
public:
// Receives a handle to the active modal dialog, or NULL when the active
// dialog is dismissed.
@@ -62,25 +45,27 @@ class TryChromeDialogView : public views::ButtonListener,
ActiveModalDialogListener;
enum Result {
- TRY_CHROME, // Launch chrome right now.
- TRY_CHROME_AS_DEFAULT, // Launch chrome and make it the default.
- NOT_NOW, // Don't launch chrome. Exit now.
- UNINSTALL_CHROME, // Initiate chrome uninstall and exit.
- DIALOG_ERROR, // An error occurred creating the dialog.
+ OPEN_CHROME, // Launch chrome right now.
+ NOT_NOW, // Don't launch chrome. Exit now.
+ DIALOG_ERROR, // An error occurred creating the dialog.
COUNT
};
// Shows a modal dialog asking the user to give chrome another try. See
// above for the possible outcomes of the function. This is an experimental,
// non-localized dialog.
// |flavor| can be 0, 1, 2 or 3 and selects what strings to present.
grt (UTC plus 2) 2017/06/22 20:34:04 flavor -> group throughout for consistency with th
skare_ 2017/06/22 23:25:18 Done.
// |listener| will be notified when the dialog becomes active and when it is
// dismissed.
// Note that the dialog has no parent and it will position itself in a lower
- // corner of the screen. The dialog does not steal focus and does not have an
- // entry in the taskbar.
- static Result Show(size_t flavor,
- const ActiveModalDialogListener& listener);
+ // corner of the screen or near the Chrome taskbar button.
+ // The dialog does not steal focus and does not have an entry in the taskbar.
+ static Result Show(size_t flavor, const ActiveModalDialogListener& listener);
+
+ // Obtains the Welcome Back page to launch for a given experime.
+ static StartupBrowserCreator::WelcomeBackPage GetWelcomePageForFlavor(
grt (UTC plus 2) 2017/06/22 20:34:04 wdyt of either having the WelcomeBackPage type bei
skare_ 2017/06/22 23:25:17 moved to being an out param and removed GetWelcome
+ size_t flavor);
+
private:
// Indicates whether the dialog is modal
enum class kDialogType {
@@ -114,30 +99,31 @@ class TryChromeDialogView : public views::ButtonListener,
// does not compete with the standard place of the start menu.
gfx::Rect ComputeWindowPosition(const gfx::Size& size, bool is_RTL);
- // Create a windows region that looks like a toast of width |w| and height
- // |h|. This is best effort, so we don't care much if the operation fails.
- void SetToastRegion(HWND window, int w, int h);
-
// views::ButtonListener:
// We have two buttons and according to what the user clicked we set |result_|
// and we should always close and end the modal loop.
void ButtonPressed(views::Button* sender, const ui::Event& event) override;
- // views::LinkListener:
- // If the user selects the link we need to fire off the default browser that
- // by some convoluted logic should not be chrome.
- void LinkClicked(views::Link* source, int event_flags) override;
-
// Controls which flavor of the heading text to use.
size_t flavor_;
- // We don't own any of these pointers. The |popup_| owns itself and owns the
- // other views.
+ // Font list used by text and buttons.
+ gfx::FontList font_list_;
+
+ // Bounds for Chrome icon on taskbar if pinned. Empty if not pinned.
+ // TODO(skare): Pull from https://codereview.chromium.org/2900653002
+ gfx::Rect chrome_taskbar_rect_;
+
+ // Time when the toast was displayed.
+ base::Time time_shown_;
+
+ // Unowned; |popup_| owns itself.
views::Widget* popup_;
- views::RadioButton* try_chrome_;
- views::RadioButton* kill_chrome_;
- views::RadioButton* dont_try_chrome_;
- views::Checkbox* make_default_;
+
+ // Experiment feedback interface.
+ installer::ExperimentStorage storage_;
+
+ // Result of displaying the dialog: accepted, dismissed, etc.
Result result_;
DISALLOW_COPY_AND_ASSIGN(TryChromeDialogView);
@@ -62,25 +45,27 @@ class TryChromeDialogView : public views::ButtonListener,
// above for the possible outcomes of the function. This is an experimental,
// non-localized dialog.
- // |flavor| can be 0, 1, 2 or 3 and selects what strings to present.
+ // |flavor| selects what strings to present and what controls are shown.
grt (UTC plus 2) 2017/06/22 20:34:04 flavor -> group throughout for consistency with th
skare_ 2017/06/22 23:25:18 Done.

Powered by Google App Engine
This is Rietveld 408576698